pub enum HeartbeatResponse {
Acknowledged(String),
Resynchronize(String),
}Expand description
Outcome from an authenticated CLOB order-safety heartbeat.
Variants
Acknowledged(String)
The heartbeat was acknowledged and the venue returned the next ID for chaining.
Resynchronize(String)
The supplied ID was stale and the venue returned the current ID.