pub struct PolymarketClobPublicClient { /* private fields */ }Expand description
Provides an unauthenticated HTTP client for public CLOB endpoints.
Unlike PolymarketClobHttpClient, this client does not require credentials
and is suitable for the data client which only needs public market data.
Implementations
Sourceimpl PolymarketClobPublicClient
impl PolymarketClobPublicClient
Sourcepub fn new(
base_url: Option<String>,
timeout_secs: u64,
) -> StdResult<Self, HttpClientError>
pub fn new( base_url: Option<String>, timeout_secs: u64, ) -> StdResult<Self, HttpClientError>
Creates a new PolymarketClobPublicClient.
Errors
Returns an error if the HTTP client cannot be created.
Sourcepub async fn get_book(&self, token_id: &str) -> Result<ClobBookResponse>
pub async fn get_book(&self, token_id: &str) -> Result<ClobBookResponse>
Fetches the order book for a token from the CLOB API.